@@ -8,7 +8,7 @@ import copy
 
 import numpy as np
 
-from .parent import Geometry
+from .parent import Geometry3D
 from .geometry import plane_transform
 from .constants import tol
 from .visual.color import VertexColor
@@ -212,7 +212,7 @@ def remove_close(points, radius):
     highest = pairs.ravel()[column + 2 * np.arange(len(column))]
 
     # mask the vertices by index
-    mask = np.ones(len(points), dtype=np.bool)
+    mask = np.ones(len(points), dtype=bool)
     mask[highest] = False
 
     if tol.strict:
@@ -249,6 +249,7 @@ def k_means(points, k, **kwargs):
 
     points = np.asanyarray(points, dtype=np.float64)
     points_std = points.std(axis=0)
+    points_std[points_std < tol.zero] = 1
     whitened = points / points_std
     centroids_whitened, distortion = kmeans(whitened, k, **kwargs)
     centroids = centroids_whitened * points_std
@@ -298,7 +299,7 @@ def tsp(points, start=0):
     start = int(start)
 
     # a mask of unvisited points by index
-    unvisited = np.ones(len(points), dtype=np.bool)
+    unvisited = np.ones(len(points), dtype=bool)
     unvisited[start] = False
 
     # traversal of points by index
@@ -375,7 +376,7 @@ def plot_points(points, show=True):
         plt.show()
 
 
-class PointCloud(Geometry):
+class PointCloud(Geometry3D):
     """
     Hold 3D points in an object which can be visualized
     in a scene.
@@ -404,6 +405,9 @@ class PointCloud(Geometry):
         # load vertices
         self.vertices = vertices
 
+        if 'vertex_colors' in kwargs and colors is None:
+            colors = kwargs['vertex_colors']
+
         # save visual data to vertex color object
         self.visual = VertexColor(colors=colors, obj=self)
 
@@ -522,7 +526,7 @@ class PointCloud(Geometry):
         Returns
         ------------
         bounds : (2, 3) float
-          Miniumum, Maximum verteex
+          Minimum, Maximum verteex
         """
         return np.array([self.vertices.min(axis=0),
                          self.vertices.max(axis=0)])
@@ -640,3 +644,6 @@ class PointCloud(Geometry):
                            file_obj=file_obj,
                            file_type=file_type,
                            **kwargs)
+
+    def __add__(self, other):
+        return PointCloud(vertices=np.vstack((self.vertices, other.vertices)))
